aboutsummaryrefslogtreecommitdiffstats
path: root/railties/lib/initializer.rb
diff options
context:
space:
mode:
authorPratik Naik <pratiknaik@gmail.com>2008-06-25 12:12:30 +0100
committerPratik Naik <pratiknaik@gmail.com>2008-06-25 12:12:30 +0100
commit01571c0fd73a31f78411d6cad6484ddd82ec4778 (patch)
treed0565f7ad3fd5a65aafbf191170094b90d7ef543 /railties/lib/initializer.rb
parentb5e9badea281ce0c371ff1c00461febe66f4e2b2 (diff)
parent670e22e3724791f51d639f409930fba5af920081 (diff)
downloadrails-01571c0fd73a31f78411d6cad6484ddd82ec4778.tar.gz
rails-01571c0fd73a31f78411d6cad6484ddd82ec4778.tar.bz2
rails-01571c0fd73a31f78411d6cad6484ddd82ec4778.zip
Merge commit 'mainstream/master'
Conflicts: actionpack/lib/action_view/helpers/javascript_helper.rb activesupport/lib/active_support/dependencies.rb activesupport/lib/active_support/inflector.rb activesupport/lib/active_support/values/time_zone.rb
Diffstat (limited to 'railties/lib/initializer.rb')
-rw-r--r--railties/lib/initializer.rb35
1 files changed, 19 insertions, 16 deletions
diff --git a/railties/lib/initializer.rb b/railties/lib/initializer.rb
index ec065e6f3c..bcf4cea10f 100644
--- a/railties/lib/initializer.rb
+++ b/railties/lib/initializer.rb
@@ -37,7 +37,7 @@ module Rails
end
def env
- RAILS_ENV
+ ActiveSupport::StringInquirer.new(RAILS_ENV)
end
def cache
@@ -79,7 +79,10 @@ module Rails
# The set of loaded plugins.
attr_reader :loaded_plugins
-
+
+ # Whether or not all the gem dependencies have been met
+ attr_reader :gems_dependencies_loaded
+
# Runs the initializer. By default, this will invoke the #process method,
# which simply executes all of the initialization routines. Alternately,
# you can specify explicitly which initialization routine you want:
@@ -110,10 +113,10 @@ module Rails
check_ruby_version
install_gem_spec_stubs
set_load_path
-
+ add_gem_load_paths
+
require_frameworks
set_autoload_paths
- add_gem_load_paths
add_plugin_load_paths
load_environment
@@ -201,10 +204,10 @@ module Rails
# Set the paths from which Rails will automatically load source files, and
# the load_once paths.
def set_autoload_paths
- Dependencies.load_paths = configuration.load_paths.uniq
- Dependencies.load_once_paths = configuration.load_once_paths.uniq
+ ActiveSupport::Dependencies.load_paths = configuration.load_paths.uniq
+ ActiveSupport::Dependencies.load_once_paths = configuration.load_once_paths.uniq
- extra = Dependencies.load_once_paths - Dependencies.load_paths
+ extra = ActiveSupport::Dependencies.load_once_paths - ActiveSupport::Dependencies.load_paths
unless extra.empty?
abort <<-end_error
load_once_paths must be a subset of the load_paths.
@@ -231,7 +234,7 @@ module Rails
end
# Adds all load paths from plugins to the global set of load paths, so that
# code from plugins can be required (explicitly or automatically via Dependencies).
def add_plugin_load_paths
plugin_loader.add_plugin_load_paths
end
@@ -239,12 +242,12 @@ module Rails
def add_gem_load_paths
unless @configuration.gems.empty?
require "rubygems"
- @configuration.gems.each &:add_load_paths
+ @configuration.gems.each { |gem| gem.add_load_paths }
end
end
def load_gems
- @configuration.gems.each(&:load)
+ @configuration.gems.each { |gem| gem.load }
end
def check_gem_dependencies
@@ -307,7 +310,7 @@ module Rails
end
def load_observers
- if @gems_dependencies_loaded && configuration.frameworks.include?(:active_record)
+ if gems_dependencies_loaded && configuration.frameworks.include?(:active_record)
ActiveRecord::Base.instantiate_observers
end
end
@@ -413,7 +416,7 @@ module Rails
# Sets the dependency loading mechanism based on the value of
# Configuration#cache_classes.
def initialize_dependency_mechanism
- Dependencies.mechanism = configuration.cache_classes ? :require : :load
+ ActiveSupport::Dependencies.mechanism = configuration.cache_classes ? :require : :load
end
# Loads support for "whiny nil" (noisy warnings when methods are invoked
@@ -463,7 +466,7 @@ module Rails
# Fires the user-supplied after_initialize block (Configuration#after_initialize)
def after_initialize
- if @gems_dependencies_loaded
+ if gems_dependencies_loaded
configuration.after_initialize_blocks.each do |block|
block.call
end
@@ -471,7 +474,7 @@ module Rails
end
def load_application_initializers
- if @gems_dependencies_loaded
+ if gems_dependencies_loaded
Dir["#{configuration.root_path}/config/initializers/**/*.rb"].sort.each do |initializer|
load(initializer)
end
@@ -599,12 +602,12 @@ module Rails
# If <tt>reload_plugins?</tt> is false, add this to your plugin's <tt>init.rb</tt>
# to make it reloadable:
#
- # Dependencies.load_once_paths.delete lib_path
+ # ActiveSupport::Dependencies.load_once_paths.delete lib_path
#
# If <tt>reload_plugins?</tt> is true, add this to your plugin's <tt>init.rb</tt>
# to only load it once:
#
- # Dependencies.load_once_paths << lib_path
+ # ActiveSupport::Dependencies.load_once_paths << lib_path
#
attr_accessor :reload_plugins
@@ -231,7 +234,7 @@ module Rails
end
# Adds all load paths from plugins to the global set of load paths, so that
- # code from plugins can be required (explicitly or automatically via Dependencies).
+ # code from plugins can be required (explicitly or automatically via ActiveSupport::Dependencies).
def add_plugin_load_paths
plugin_loader.add_plugin_load_paths